import React, { useState } from "react";
import { Modal, Box, Typography, IconButton, TextField } from "@mui/material";
import CloseIcon from "@mui/icons-material/Close";
import { ClipLoader } from "react-spinners";
import { isAutheticated } from "src/auth";
import { toast } from "react-hot-toast";
import axios from "axios";
const style = {
  position: "absolute",
  top: "50%",
  left: "50%",
  transform: "translate(-50%, -50%)",
  bgcolor: "background.paper",
  borderRadius: "0.5rem",
  boxShadow: 24,
  width: "500px",
};
const BrandModal = ({
  open,
  setOpen,
  brandName,
  setBrandName,
  edit,
  handleSaveBrand,
  handleUpdate,
  saveLoading,
  updating,
  existingImage,
  setExistingImage,
  handleClose,
  getBrands,
}) => {
  const [selectedImage, setSelectedImage] = useState(null);

  const handleFileChange = (event) => {
    const file = event.target.files[0];
    if (file) {
      setSelectedImage(file);
    }
  };
  const handleDeleteImage = (url, public_id) => {
    if (public_id) {
      // Retrieve the authentication token
      const token = isAutheticated(); // Ensure this function
      const encodedPublicId = encodeURIComponent(public_id);
      // console.log("public_id:", public_id); // Log to debug
      // console.log("encodedPublicId:", encodedPublicId); // Log to debug
      // Delete image from Cloudinary
      axios
        .delete(`/api/brand/deleteImage/${encodedPublicId}`, {
          headers: {
            Authorization: `Bearer ${token}`, // Include the token in the headers
          },
        })
        .then(() => {
          setExistingImage(null);
          getBrands();
          toast.success("Image deleted successfully");
        })
        .catch((err) => {
          console.error(err.response?.data);
        });
    }
  };
  const handleRemoveImage = () => {
    if (existingImage) {
      handleDeleteImage(existingImage.url, existingImage.public_id);
    } else {
      setSelectedImage(null);
    }
  };
  return (
    <Modal
      open={open}
      onClose={handleClose}
      aria-labelledby="modal-modal-title"
      aria-describedby="modal-modal-description"
    >
      <Box sx={style}>
        <Box p={2} display={"flex"}>
          <Typography
            id="modal-modal-title"
            variant="body"
            component="h2"
            flex={1}
          >
            Brand Name
          </Typography>
          <IconButton
            onClick={() => {
              handleClose();
              setSelectedImage(null);
            }}
          >
            <CloseIcon />
          </IconButton>
        </Box>
        <hr />
        <TextField
          placeholder="brand name"
          value={brandName}
          fullWidth
          inputProps={{
            maxLength: 25,
          }}
          style={{
            padding: "1rem",
          }}
          onChange={(e) =>
            setBrandName(
              e.target.value.charAt(0).toUpperCase() + e.target.value.slice(1)
            )
          }
        />
        {brandName ? (
          <>
            <small className="charLeft mt-2 ml-3 fst-italic">
              {25 - brandName.length} characters left
            </small>
          </>
        ) : (
          <></>
        )}
        {/* Image Upload Section */}
        <Box mt={2} className="d-flex ml-3">
          {existingImage ? (
            <Box>
              <img
                src={existingImage.url}
                alt="Brand"
                width={200}
                height={200}
                style={{
                  objectFit: "contain",
                  borderRadius: 8,
                  border: "1px solid #ccc",
                }}
              />
              <button
                onClick={handleRemoveImage}
                style={{ background: "red", color: "white", marginTop: 8, marginLeft: 8 }}
              >
                Delete Image
              </button>
            </Box>
          ) : selectedImage ? (
            <Box>
              <img
                src={URL.createObjectURL(selectedImage)}
                alt="Preview"
                width={200}
                height={200}
                style={{
                  objectFit: "contain",
                  borderRadius: 8,
                  border: "1px solid #ccc", // Optional border for clarity
                }}
              />
              <button
                onClick={handleRemoveImage}
                style={{ background: "red", color: "white", marginTop: 8, marginLeft: 8 }}
              >
                Remove Image
              </button>
            </Box>
          ) : (
            <input type="file" accept="image/*" onChange={handleFileChange} />
          )}
        </Box>

        <Box
          p={2}
          display={"flex"}
          justifyContent={"right"}
          // width={"500px"}
        >
          {!edit && (
            <button
              style={{
                color: "white",
                marginRight: "1rem",
              }}
              onClick={() =>
                handleSaveBrand(brandName, selectedImage, () =>
                  setSelectedImage(null)
                )
              }
              type="button"
              className="
                       btn btn-primary btn-sm
                     waves-effect waves-light
                     btn-table
                     mx-1
                     mt-1
                   "
            >
              <ClipLoader loading={saveLoading} size={18} />
              {saveLoading || "Save"}
            </button>
          )}
          {edit && (
            <button
              style={{
                color: "white",
                marginRight: "1rem",
              }}
              onClick={() =>
                handleUpdate(brandName, selectedImage, () =>
                  setSelectedImage(null)
                )
              }
              type="button"
              className="
                       btn btn-primary btn-sm
                     waves-effect waves-light
                     btn-table
                     mx-1
                     mt-1
                   "
            >
              <ClipLoader loading={updating} size={18} />
              {updating || "update"}
            </button>
          )}
          <button
            style={{
              color: "black",
              marginRight: "1rem",
              background: "grey",
            }}
            onClick={() => {
              setOpen(false);
              setSelectedImage(null);
            }}
            type="button"
            className="
                       btn  btn-sm
                     waves-effect waves-light
                     btn-table
                     mx-1
                     mt-1
                   "
          >
            Close
          </button>
        </Box>
      </Box>
    </Modal>
  );
};

export default BrandModal;
